@@ -6,20 +6,7 @@ Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 partially based on C++ code from:
  - Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
+SPDX-License-Identifier: GPL-2.0
 
 """
 
@@ -32,10 +19,9 @@ from collections import defaultdict
 import sqlite3
 
 from mi18n import i18n, i18ncE
-from kde import appdataDir
 from util import Duration
 from log import logInfo, logWarning, logException, logError, logDebug, id4
-from common import IntDict, Options, Internal, Debug
+from common import IntDict, Options, Internal, Debug, appdataDir
 
 class QueryException(Exception):
 
@@ -99,15 +85,14 @@ class DBCursor(sqlite3.Cursor):
             else:
                 if not failSilent:
                     logError(msg)
-                raise QueryException(msg)
+                raise QueryException(msg) from exc
             return
 
     def __str__(self):
         """the statement"""
         if self.parameters is not None:
             return "{cmd} [{args}]".format(cmd=self.statement, args=self.parameters)
-        else:
-            return self.statement
+        return self.statement
 
 
 class DBHandle(sqlite3.Connection):
@@ -167,7 +152,7 @@ class DBHandle(sqlite3.Connection):
     @property
     def name(self):
         """get name for log messages. Readonly."""
-        stack = list(x[2] for x in traceback.extract_stack())
+        stack = [x[2] for x in traceback.extract_stack()]
         name = stack[-3]
         if name in ('__exit__', '__init__'):
             name = stack[-4]
@@ -213,7 +198,7 @@ class DBHandle(sqlite3.Connection):
     @staticmethod
     def hasTable(table):
         """does the table contain table?"""
-        return bool(len(Query('SELECT name FROM sqlite_master WHERE type="table" AND name="%s"' % table).records))
+        return len(Query('SELECT name FROM sqlite_master WHERE type="table" AND name="%s"' % table).records) > 0
 
     def tableHasField(self, table, field):
         """does the table contain a column named field?"""
@@ -273,10 +258,7 @@ class Query:
 
     def rowcount(self):
         """how many rows were affected?"""
-        if self.cursor:
-            return self.cursor.rowcount
-        else:
-            return 0
+        return self.cursor.rowcount if self.cursor else 0
 
 
 def initDb():
@@ -392,8 +374,7 @@ class PrepareDB:
         """
         if Internal.db.tableHasField('general', 'schemaversion'):
             return Query('select schemaversion from general').records[0][0]
-        else:
-            return '1.1.1'
+        return '1.1.1'
 
     def __upgrade(self):
         """upgrade the structure of an existing kajongg database"""
