@@ -3,19 +3,8 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 import datetime
@@ -84,7 +73,7 @@ class SelectPlayers(SelectRuleset):
 
         query = Query(
             "select p0,p1,p2,p3 from game where seed is null and game.id = (select max(id) from game)")
-        if len(query.records):
+        if query.records:
             with BlockSignals(self.nameWidgets):
                 for cbName, playerId in zip(self.nameWidgets, query.records[0]):
                     try:
@@ -97,13 +86,13 @@ class SelectPlayers(SelectRuleset):
                                  % playerId)
         self.slotValidate()
 
-    def showEvent(self, dummyEvent):
+    def showEvent(self, unusedEvent):
         """start with player 0"""
         self.nameWidgets[0].setFocus()
 
     def __selectedNames(self):
         """A set with the currently selected names"""
-        return set(list(cbName.currentText() for cbName in self.nameWidgets))
+        return {cbName.currentText() for cbName in self.nameWidgets}
 
     def slotValidate(self):
         """try to find 4 different players and update status of the Ok button"""
@@ -114,8 +103,7 @@ class SelectPlayers(SelectRuleset):
         allNames = set(Players.humanNames.values())
         unusedNames = allNames - self.__selectedNames()
         with BlockSignals(self.nameWidgets):
-            used = set([x.currentText()
-                        for x in self.nameWidgets if x.manualSelect])
+            used = {x.currentText() for x in self.nameWidgets if x.manualSelect}
             for combo in self.nameWidgets:
                 if not combo.manualSelect:
                     if combo.currentText() in used:
@@ -128,12 +116,11 @@ class SelectPlayers(SelectRuleset):
                 combo.clear()
                 combo.addItems([comboName])
                 combo.addItems(sorted(
-                    allNames - self.__selectedNames() - set([comboName])))
+                    allNames - self.__selectedNames() - {comboName}))
                 combo.setCurrentIndex(0)
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(
             len(self.__selectedNames()) == 4)
-        self.names = list(cbName.currentText()
-                          for cbName in self.nameWidgets)
+        self.names = [cbName.currentText() for cbName in self.nameWidgets]
 
 
 class ScoringTileAttr(TileAttr):
@@ -144,7 +131,7 @@ class ScoringTileAttr(TileAttr):
         """should the tile appear darker?"""
         return self.yoffset or self.tile.isConcealed
 
-    def setFocusable(self, dummyHand, dummyMeld, idx):
+    def setFocusable(self, hand, meld, idx):
         """in a scoring handboard, only the first tile of a meld is focusable"""
         return idx == 0
 
@@ -178,16 +165,18 @@ class ScoringHandBoard(HandBoard):
         return self.uiMeldWithTile(uiTile)[0]
 
     def uiMeldWithTile(self, uiTile):
-        """returns the meld with uiTile"""
+        """return the meld with uiTile"""
         for myMeld in self.uiMelds:
             if uiTile in myMeld:
                 return myMeld
+        return None
 
     def findUIMeld(self, meld):
         """find the first UIMeld matching the logical meld"""
         for result in self.uiMelds:
             if result.meld == meld:
                 return result
+        return None
 
     def assignUITiles(self, uiTile, meld):  # pylint: disable=unused-argument
         """generate a UIMeld. First uiTile is given, the rest should be as defined by meld"""
@@ -244,9 +233,9 @@ class ScoringHandBoard(HandBoard):
         if not newMeld:
             return False
         uiMeld = senderBoard.assignUITiles(uiTile, newMeld)
-        for uiTile, tile in zip(uiMeld, newMeld):
-            uiTile.tile = tile
-        self.dropMeld(uiMeld)
+        for uitile, tile in zip(uiMeld, newMeld):
+            uitile.tile = tile
+        return self.dropMeld(uiMeld)
 
     def dropMeld(self, uiMeld):
         """drop uiMeld into our hand"""
@@ -255,7 +244,7 @@ class ScoringHandBoard(HandBoard):
         self.uiMelds.append(uiMeld)
         self.player.addMeld(uiMeld.meld)
         self.sync()
-        self.hasFocus = senderBoard == self or not senderBoard.uiTiles
+        self.hasLogicalFocus = senderBoard == self or not senderBoard.uiTiles
         self.checkTiles()
         senderBoard.autoSelectTile()
         senderBoard.checkTiles()
@@ -270,10 +259,7 @@ class ScoringHandBoard(HandBoard):
         """how many tiles are in focus rect? We want to focus
         the entire meld"""
         meld = self.uiMeldWithTile(self.focusTile)
-        if meld:
-            return len(meld)
-        else:
-            return 1
+        return len(meld) if meld else 1
 
     def addUITile(self, uiTile):
         Board.addUITile(self, uiTile)
@@ -346,10 +332,11 @@ class ScoringPlayer(VisiblePlayer, Player):
         if isAlive(self.handBoard):
             self.handBoard.setEnabled(True)
             self.handBoard.showMoveHelper()
+            self.handBoard.uiMelds = []
         self.manualRuleBoxes = []
 
     def explainHand(self):
-        """returns the hand to be explained"""
+        """return the hand to be explained"""
         return self.hand
 
     @property
@@ -358,8 +345,7 @@ class ScoringPlayer(VisiblePlayer, Player):
         if self.hasManualScore():
             spValue = Internal.scene.scoringDialog.spValues[self.idx]
             return spValue.value()
-        else:
-            return self.hand.total()
+        return self.hand.total()
 
     def hasManualScore(self):
         """True if no tiles are assigned to this player"""
@@ -429,7 +415,7 @@ class ScoringPlayer(VisiblePlayer, Player):
         return 'L%s%s' % (self.lastTile, self.lastMeld)
 
     def computeHand(self):
-        """returns a Hand object, using a cache"""
+        """return a Hand object, using a cache"""
         self.lastTile = Internal.scene.computeLastTile()
         self.lastMeld = Internal.scene.computeLastMeld()
         string = ' '.join(
@@ -440,12 +426,11 @@ class ScoringPlayer(VisiblePlayer, Player):
 
     def sortRulesByX(self, rules):
         """if this game has a GUI, sort rules by GUI order of the melds they are applied to"""
-        withMelds = list(x for x in rules if x.meld)
-        withoutMelds = list(x for x in rules if x not in withMelds)
-        tuples = list(tuple([x, self.handBoard.findUIMeld(x.meld)])
-                      for x in withMelds)
+        withMelds = [x for x in rules if x.meld]
+        withoutMelds = [x for x in rules if x not in withMelds]
+        tuples = [tuple([x, self.handBoard.findUIMeld(x.meld)]) for x in withMelds]
         tuples = sorted(tuples, key=lambda x: x[1][0].sortKey())
-        return list(x[0] for x in tuples) + withoutMelds
+        return [x[0] for x in tuples] + withoutMelds
 
     def addMeld(self, meld):
         """add meld to this hand in a scoring game"""
@@ -516,7 +501,7 @@ class ScoringGame(Game):
         self.throwDices()
 
     @Game.seed.getter
-    def seed(self):
+    def seed(self): # looks like a pylint bug pylint: disable=invalid-overridden-method
         """a scoring game never has a seed"""
         return None
 
@@ -530,7 +515,7 @@ class ScoringGame(Game):
         if not self.finished():
             selector = Internal.scene.selectorBoard
             selector.refill()
-            selector.hasFocus = True
+            selector.hasLogicalFocus = True
             self.wall.build(shuffleFirst=False)
 
     def nextScoringHand(self):
@@ -590,7 +575,7 @@ class ScoringGame(Game):
         # I do not understand the logic of the exec return value. The yes button returns 0
         # and the no button returns 1. According to the C++ doc, the return value is an
         # opaque value that should not be used."""
-        return list(x for x in pairs if SwapDialog(x).exec_() == 0)
+        return [x for x in pairs if SwapDialog(x).exec_() == 0]
 
     def savePenalty(self, player, offense, amount):
         """save computed values to database, update score table and balance in status line"""
@@ -612,17 +597,16 @@ def scoreGame():
     if len(Players.humanNames) < 4:
         logWarning(
             i18n('Please define four players in <interface>Settings|Players</interface>'))
-        return
+        return None
     gameSelector = Games(Internal.mainWindow)
     selected = None
     if not gameSelector.exec_():
-        return
+        return None
     selected = gameSelector.selectedGame
     gameSelector.close()
     if selected is not None:
         return ScoringGame.loadFromDB(selected)
-    else:
-        selectDialog = SelectPlayers()
-        if not selectDialog.exec_():
-            return
-        return ScoringGame(list(zip(Wind.all4, selectDialog.names)), selectDialog.cbRuleset.current)
+    selectDialog = SelectPlayers()
+    if not selectDialog.exec_():
+        return None
+    return ScoringGame(list(zip(Wind.all4, selectDialog.names)), selectDialog.cbRuleset.current)
